/*
 * Material Google Font Choosers
 * Created by Patrick Kelly
 * https://butterflydesign.me
 * 
 * Copyright (c) 2020 butterfly design, LLC. All rights reserved.
 * See LICENSE for distribution and usage details.
 */
library material_google_fonts_choosers;

import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class MaterialGoogleFontSearchInput extends StatefulWidget {
  final InputDecoration inputDecoration;
  final Function confirm;

  MaterialGoogleFontSearchInput({this.confirm, this.inputDecoration});
  @override
  _MaterialGoogleFontSearchInputState createState() =>
      _MaterialGoogleFontSearchInputState();
}

class _MaterialGoogleFontSearchInputState
    extends State<MaterialGoogleFontSearchInput> {
  String currentSearchMatch = "No matches";
  String currentValue = "Search for a better font";
  int threshold = 3;

  _MaterialGoogleFontSearchInputState();

//Search the Google Fonts API

  int searchGoogleFonts(String value) {
    // TODO set up a debounce
    // We are going to call [fonts.google.com] after 3 chars
    // search fonts list to see if we have a match.
    if (value.length > threshold) {
      return MaterialGoogleFontChoosers.fontsList
          .indexWhere((s) => s.contains(value));
    }
    return null;
  }

  updateCurrentSearchMatch(int index) {
    setState(() {
      currentSearchMatch = MaterialGoogleFontChoosers.fontsList[index];
    });
  }

  //Comment this out before release so they have to create thier own confirmation logic. I want ot keep this agnostic

  onChanged(String value) => searchGoogleFonts(value);

  //A basic input widget
  //So you can style it as you need
  input(decoration) => TextField(decoration: decoration, onChanged: onChanged);

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width * 0.6;
    return Container(
      width: width,
      child: Column(
        children: <Widget>[
          input(widget.inputDecoration),
          FlatButton(
              child: Text(currentSearchMatch), onPressed: widget.confirm),
        ],
      ),
    );
  }
}

/// A Calculator.
class GoogleFontProvider {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}
/*
 * Material Google Font Choosers
 * Created by Patrick Kelly
 * https://butterflydesign.me
 * 
 * Copyright (c) 2020 butterfly design, LLC. All rights reserved.
 * See LICENSE for distribution and usage details.
 */

class MaterialGoogleFontsDropDown extends StatefulWidget {
  const MaterialGoogleFontsDropDown({
    Key key,
  }) : super(key: key);
  @override
  _FontSwitcherState createState() => _FontSwitcherState();
}

class _FontSwitcherState extends State<MaterialGoogleFontsDropDown> {
  String dropdownValue = "Select Font";

  @override
  Widget build(BuildContext context) {
    var dropdownButton = DropdownButton<String>(
      value: dropdownValue,
      icon: Icon(Icons.arrow_downward),
      iconSize: 24,
      elevation: 16,
      style: TextStyle(color: Colors.deepPurple),
      underline: Container(
        height: 2,
        color: Colors.deepPurpleAccent,
      ),
      onChanged: (String newValue) {
        setState(() {
          dropdownValue = newValue;
        });
      },
      items: MaterialGoogleFontChoosers.fontsList
          .map<DropdownMenuItem<String>>((String value) {
        return DropdownMenuItem<String>(value: value, child: Text(value));
      }).toList(),
    );
    return dropdownButton;
  }

  buidlFontTheme() {
    for (var font in MaterialGoogleFontChoosers.fontsList) {
      GoogleFonts.getFont(font);
    }
  }
}

/*
 * Material Google Font Choosers
 * Created by Patrick Kelly
 * https://butterflydesign.me
 * 
 * Copyright (c) 2020 butterfly design, LLC. All rights reserved.
 * See LICENSE for distribution and usage details.
 */
class MaterialGoogleFontChoosers {
  static final List<String> fontsList = [
    "Roboto",
    "Gelasio",
    "IbarraRealNova",
    "OpenSans",
    "Lato",
    "Montserrat",
    "LibreCaslonText",
    "RobotoCondensed",
    "SourceSansPro",
    "Oswald",
    "Gayathri",
    "Raleway",
    "RobotoMono",
    "Poppins",
    "NotoSans",
    "Merriweather",
    "RobotoSlab",
    "Alata",
    "PTSans",
    "Ubuntu",
    "PlayfairDisplay",
    "OpenSansCondensed",
    "Muli",
    "PTSerif",
    "Lora",
    "IMFellGreatPrimerSC",
    "Nunito",
    "Slabo27px",
    "TitilliumWeb",
    "NotoSansJP",
    "Rubik",
    "FiraSans",
    "Baskervville",
    "NotoSerif",
    "WorkSans",
    "NanumGothic",
    "PTSansNarrow",
    "Quicksand",
    "NotoSansKR",
    "Arimo",
    "Inconsolata",
    "NunitoSans",
    "NotoSansTC",
    "Heebo",
    "Dosis",
    "Barlow",
    "Oxygen",
    "YanoneKaffeesatz",
    "LibreBaskerville",
    "Karla",
    "Cabin",
    "Bitter",
    "Amarante",
    "Hind",
    "CrimsonText",
    "LibreFranklin",
    "JosefinSans",
    "Abel",
    "Anton",
    "FjallaOne",
    "Mukta",
    "IndieFlower",
    "SourceCodePro",
    "Lobster",
    "BarlowCondensed",
    "PublicSans",
    "Kanit",
    "Pacifico",
    "VarelaRound",
    "DancingScript",
    "Arvo",
    "MavenPro",
    "Exo2",
    "SourceSerifPro",
    "MerriweatherSans",
    "ShadowsIntoLight",
    "EBGaramond",
    "PortLligatSans",
    "HindSiliguri",
    "Overpass",
    "Bangers",
    "IBMPlexSans",
    "Acme",
    "AbrilFatface",
    "BreeSerif",
    "ArchivoNarrow",
    "Asap",
    "Comfortaa",
    "Questrial",
    "Teko",
    "Signika",
    "Cairo",
    "ZhiMangXing",
    "ZillaSlab",
    "Catamaran",
    "BebasNeue",
    "Righteous",
    "Exo",
    "FiraSansCondensed",
    "AmaticSC",
    "Play",
    "PTSansCaption",
    "UbuntuCondensed",
    "Domine",
    "CreteRound",
    "PermanentMarker",
    "Monda",
    "Fruktur",
    "Prompt",
    "PatuaOne",
    "Caveat",
    "Martel",
    "Cinzel",
    "Vollkorn",
    "Assistant",
    "CormorantGaramond",
    "Rajdhani",
    "RopaSans",
    "NotoSansSC",
    "ABeeZee",
    "Rokkitt",
    "FredokaOne",
    "FrancoisOne",
    "Cuprum",
    "Courgette",
    "Satisfy",
    "Alegreya",
    "HindMadurai",
    "InriaSerif",
    "LuckiestGuy",
    "NewsCycle",
    "AlegreyaSans",
    "AlfaSlabOne",
    "Kalam",
    "PathwayGothicOne",
    "BowlbyOneSC",
    "Cardo",
    "CourierPrime",
    "NoticiaText",
    "BarlowSemiCondensed",
    "KaushanScript",
    "Amiri",
    "GreatVibes",
    "Tajawal",
    "ArchivoBlack",
    "Tinos",
    "NanumMyeongjo",
    "IBMPlexSerif",
    "FiraSansExtraCondensed",
    "Girassol",
    "Vidaloka",
    "QuattrocentoSans",
    "LobsterTwo",
    "NotoSerifJP",
    "OldStandardTT",
    "IstokWeb",
    "Sacramento",
    "PassionOne",
    "ConcertOne",
    "Cantarell",
    "Changa",
    "DidactGothic",
    "SpecialElite",
    "PatrickHand",
    "Volkhov",
    "GloriaHallelujah",
    "FrankRuhlLibre",
    "GothicA1",
    "Orbitron",
    "SairaExtraCondensed",
    "MPLUS1p",
    "Quattrocento",
    "AdventPro",
    "Cookie",
    "PoiretOne",
    "HindVadodara",
    "Neuton",
    "Prata",
    "SixCaps",
    "BenchNine",
    "Economica",
    "MontserratAlternates",
    "RussoOne",
    "Chivo",
    "PlayfairDisplaySC",
    "Sanchez",
    "Handlee",
    "JosefinSlab",
    "Ruda",
    "SawarabiMincho",
    "Lalezar",
    "Viga",
    "Archivo",
    "Neucha",
    "Gudea",
    "BalooBhai",
    "SeymourOne",
    "GochiHand",
    "MPLUSRounded1c",
    "PTMono",
    "PaytoneOne",
    "Electrolize",
    "Armata",
    "SairaCondensed",
    "Parisienne",
    "Yantramanav",
    "Khand",
    "Philosopher",
    "Ultra",
    "CabinCondensed",
    "Quantico",
    "SquadaOne",
    "ElMessiri",
    "HindGuntur",
    "ArchitectsDaughter",
    "UnicaOne",
    "Gupter",
    "HammersmithOne",
    "Arapey",
    "Alice",
    "PontanoSans",
    "IBMPlexMono",
    "Yellowtail",
    "Spectral",
    "Monoton",
    "MarckScript",
    "Jaldi",
    "Enriqueta",
    "Alatsi",
    "PressStart2P",
    "Mitr",
    "GentiumBasic",
    "Amaranth",
    "ZCOOLQingKeHuangYou",
    "Tangerine",
    "PragatiNarrow",
    "OleoScript",
    "Saira",
    "Actor",
    "Kreon",
    "Calistoga",
    "Playball",
    "NanumGothicCoding",
    "CantataOne",
    "JuliusSansOne",
    "OdibeeSans",
    "Yrsa",
    "Audiowide",
    "FugazOne",
    "GentiumBookBasic",
    "Pridi",
    "HomemadeApple",
    "AsapCondensed",
    "Baloo",
    "SignikaNegative",
    "Allura",
    "BadScript",
    "Taviraj",
    "SairaSemiCondensed",
    "PinyonScript",
    "Adamina",
    "Allerta",
    "SortsMillGoudy",
    "Merienda",
    "RockSalt",
    "Chewy",
    "Glegoo",
    "Sintony",
    "Lusitana",
    "EncodeSans",
    "Sarabun",
    "Karma",
    "Cormorant",
    "Tomorrow",
    "CoveredByYourGrace",
    "Rasa",
    "BlackOpsOne",
    "Sarala",
    "NanumPenScript",
    "PTSerifCaption",
    "ShadowsIntoLightTwo",
    "Unna",
    "SigmarOne",
    "Varela",
    "CarterOne",
    "Scada",
    "Khula",
    "ReenieBeanie",
    "Damion",
    "Palanquin",
    "UbuntuMono",
    "Marcellus",
    "Michroma",
    "SawarabiGothic",
    "Jura",
    "Antic",
    "ArbutusSlab",
    "MrDafoe",
    "Frijole",
    "Boogaloo",
    "MarkaziText",
    "AlexBrush",
    "Aclonica",
    "Rambla",
    "Spinnaker",
    "AbhayaLibre",
    "YesevaOne",
    "NothingYouCouldDo",
    "Basic",
    "Alef",
    "AnticSlab",
    "Niramit",
    "AlegreyaSansSC",
    "CaveatBrush",
    "ZCOOLXiaoWei",
    "Lustria",
    "Coda",
    "ReemKufi",
    "CormorantInfant",
    "Rancho",
    "LexendZetta",
    "Staatliches",
    "Aldrich",
    "DMSans",
    "FrederickatheGreat",
    "Bevan",
    "MountainsofChristmas",
    "TenorSans",
    "LilitaOne",
    "Cousine",
    "Hanuman",
    "Average",
    "VT323",
    "ShareTechMono",
    "KulimPark",
    "Italianno",
    "Forum",
    "Marmelad",
    "Rochester",
    "Sunflower",
    "CabinSketch",
    "Eczar",
    "MarcellusSC",
    "Miniver",
    "LondrinaSolid",
    "Shrikhand",
    "Rufina",
    "Biryani",
    "Lemonada",
    "AllertaStencil",
    "Oranienbaum",
    "EncodeSansCondensed",
    "Nobile",
    "Ramabhadra",
    "RacingSansOne",
    "Niconne",
    "Syncopate",
    "RubikMonoOne",
    "Share",
    "Overlock",
    "Pangolin",
    "Telex",
    "Cambay",
    "Lateef",
    "Allan",
    "MiriamLibre",
    "ComingSoon",
    "AnonymousPro",
    "Aladin",
    "BerkshireSwash",
    "Magra",
    "SpaceMono",
    "SulphurPoint",
    "NotoSerifSC",
    "DaysOne",
    "JustAnotherHand",
    "MartelSans",
    "CinzelDecorative",
    "Candal",
    "Molengo",
    "BigShouldersDisplay",
    "BigShouldersText",
    "Judson",
    "FaunaOne",
    "MuktaMalar",
    "EncodeSansExpanded",
    "FiraMono",
    "Arsenal",
    "LeckerliOne",
    "Scheherazade",
    "ArimaMadurai",
    "Kameron",
    "DMSerifText",
    "Itim",
    "Halant",
    "OverpassMono",
    "Lekton",
    "ContrailOne",
    "Pattaya",
    "Gruppo",
    "ChangaOne",
    "Coustard",
    "Mali",
    "Norican",
    "AnnieUseYourTelescope",
    "RedHatDisplay",
    "Copse",
    "Yesteryear",
    "BungeeInline",
    "GrandHotel",
    "LexendPeta",
    "Radley",
    "AlegreyaSC",
    "TitanOne",
    "Sriracha",
    "Shojumaru",
    "Aleo",
    "Bentham",
    "Kristi",
    "NotoSerifTC",
    "NanumBrushScript",
    "KosugiMaru",
    "Caudex",
    "TurretRoad",
    "BalooBhaijaan",
    "DoHyeon",
    "Jomolhari",
    "Mada",
    "CarroisGothic",
    "PetitFormalScript",
    "BaiJamjuree",
    "Krub",
    "Rosario",
    "LexendDeca",
    "GFSDidot",
    "Graduate",
    "NixieOne",
    "Belleza",
    "Buenard",
    "HerrVonMuellerhoff",
    "Marvel",
    "Slabo13px",
    "Arizonia",
    "Carme",
    "RozhaOne",
    "Bungee",
    "JockeyOne",
    "BeVietnam",
    "Capriola",
    "Faustina",
    "BlackHanSans",
    "ChakraPetch",
    "Kadwa",
    "PalanquinDark",
    "Delius",
    "Rye",
    "Convergence",
    "Suranna",
    "KellySlab",
    "GildaDisplay",
    "Metrophobic",
    "CutiveMono",
    "MeriendaOne",
    "AverageSans",
    "Mallanna",
    "BalooBhaina",
    "Ovo",
    "BubblegumSans",
    "IBMPlexSansCondensed",
    "Mansalva",
    "Voltaire",
    "LoveYaLikeASister",
    "Trirong",
    "Schoolbell",
    "MrDeHaviland",
    "NTR",
    "RalewayDots",
    "Maitree",
    "DMSerifDisplay",
    "Calligraffitti",
    "Gurajada",
    "NotoSerifKR",
    "OxygenMono",
    "Poly",
    "MuktaVaani",
    "Federo",
    "Amethysta",
    "GoudyBookletter1911",
    "Sansita",
    "CevicheOne",
    "Laila",
    "Cutive",
    "FreckleFace",
    "IMFellDoublePica",
    "AveriaSerifLibre",
    "SueEllenFrancisco",
    "EmilysCandy",
    "Andada",
    "VesperLibre",
    "Baumans",
    "CantoraOne",
    "Gabriela",
    "DuruSans",
    "Trocchi",
    "Anaheim",
    "CedarvilleCursive",
    "Cambo",
    "Knewave",
    "Athiti",
    "SuezOne",
    "Amiko",
    "VastShadow",
    "Mate",
    "Battambang",
    "Pompiere",
    "Homenaje",
    "SecularOne",
    "IMFellEnglish",
    "DoppioOne",
    "Inder",
    "WendyOne",
    "FanwoodText",
    "RuslanDisplay",
    "DavidLibre",
    "Oregano",
    "Lemon",
    "EncodeSansSemiExpanded",
    "LexendExa",
    "LexendTera",
    "LexendGiga",
    "LexendMega",
    "Fresca",
    "SpicyRice",
    "Sniglet",
    "Balthazar",
    "SeaweedScript",
    "Montez",
    "Sofia",
    "SpectralSC",
    "Zeyada",
    "CraftyGirls",
    "Alike",
    "Chonburi",
    "FasterOne",
    "Wallpoet",
    "ChelseaMarket",
    "Limelight",
    "Corben",
    "Harmattan",
    "Livvic",
    "Esteban",
    "LaBelleAurore",
    "ShareTech",
    "Kurale",
    "Kosugi",
    "ProzaLibre",
    "Quando",
    "GravitasOne",
    "Strait",
    "McLaren",
    "Megrim",
    "PatrickHandSC",
    "Farro",
    "UnifrakturMaguntia",
    "Amita",
    "GiveYouGlory",
    "CormorantSC",
    "K2D",
    "StardosStencil",
    "Artifika",
    "Brawler",
    "WaitingfortheSunrise",
    "OleoScriptSwashCaps",
    "BowlbyOne",
    "AguafinaScript",
    "MontserratSubrayada",
    "ClickerScript",
    "OverlockSC",
    "Mirza",
    "Qwigley",
    "Fondamento",
    "Jua",
    "RougeScript",
    "CarroisGothicSC",
    "TheGirlNextDoor",
    "DenkOne",
    "NovaSquare",
    "Unkempt",
    "FingerPaint",
    "Rakkas",
    "Podkova",
    "Belgrano",
    "Skranji",
    "AlikeAngular",
    "SedgwickAve",
    "Englebert",
    "MrsSaintDelafield",
    "Spirax",
    "Blinker",
    "ShortStack",
    "NotoSansHK",
    "HappyMonkey",
    "MouseMemoirs",
    "WalterTurncoat",
    "ExpletusSans",
    "DarkerGrotesque",
    "CormorantUpright",
    "Meddon",
    "Gugi",
    "FjordOne",
    "Iceland",
    "SirinStencil",
    "Charm",
    "Andika",
    "Timmana",
    "Literata",
    "Tauri",
    "BungeeShade",
    "Voces",
    "PollerOne",
    "EuphoriaScript",
    "KronaOne",
    "LovedbytheKing",
    "Lacquer",
    "Bellefair",
    "AveriaSansLibre",
    "Numans",
    "IMFellDWPica",
    "LibreBarcode39",
    "Katibeh",
    "Puritan",
    "PrincessSofia",
    "Rationale",
    "RammettoOne",
    "BilboSwashCaps",
    "Gafata",
    "DeliusSwashCaps",
    "SairaStencilOne",
    "CherrySwash",
    "Mako",
    "Ledger",
    "Shanti",
    "ProstoOne",
    "DawningofaNewDay",
    "Ruluko",
    "BalooTamma",
    "Imprima",
    "Koulen",
    "Mogra",
    "HoltwoodOneSC",
    "Galada",
    "Orienta",
    "Barriecito",
    "Bahianita",
    "ArefRuqaa",
    "KumarOne",
    "Tienne",
    "LilyScriptOne",
    "Codystar",
    "OvertheRainbow",
    "Sarpanch",
    "BalooChettan",
    "Pavanam",
    "Crushed",
    "LifeSavers",
    "Almarai",
    "Salsa",
    "NovaMono",
    "ScopeOne",
    "SonsieOne",
    "HeadlandOne",
    "Geo",
    "WireOne",
    "VampiroOne",
    "EncodeSansSemiCondensed",
    "Padauk",
    "B612Mono",
    "IMFellEnglishSC",
    "Ranchers",
    "FontdinerSwanky",
    "Creepster",
    "Atma",
    "BalooPaaji",
    "AnticDidone",
    "ZillaSlabHighlight",
    "Eater",
    "RedHatText",
    "YatraOne",
    "MedulaOne",
    "HanaleiFill",
    "PortLligatSlab",
    "Mandali",
    "BubblerOne",
    "Kranky",
    "Ewert",
    "CodaCaption",
    "B612",
    "BioRhyme",
    "Sail",
    "Dynalight",
    "Slackey",
    "JustMeAgainDownHere",
    "Chathura",
    "Bahiana",
    "VollkornSC",
    "Vibur",
    "TulpenOne",
    "Dokdo",
    "AveriaLibre",
    "CherryCreamSoda",
    "RibeyeMarrow",
    "JacquesFrancoisShadow",
    "BalooDa",
    "MuktaMahee",
    "KottaOne",
    "Quintessential",
    "TradeWinds",
    "Habibi",
    "BalooThambi",
    "Farsan",
    "FascinateInline",
    "Engagement",
    "BethEllen",
    "Manjari",
    "Asul",
    "Rosarivo",
    "AveriaGruesaLibre",
    "Elsie",
    "MateSC",
    "Almendra",
    "Srisakdi",
    "Trochut",
    "Arya",
    "GermaniaOne",
    "SreeKrushnadevaraya",
    "FiraCode",
    "Peralta",
    "Bilbo",
    "PirataOne",
    "LeagueScript",
    "MysteryQuest",
    "Sarina",
    "Sumana",
    "Ribeye",
    "Vibes",
    "Condiment",
    "Prociono",
    "Unlock",
    "Italiana",
    "Coiny",
    "Metamorphous",
    "DonegalOne",
    "Simonetta",
    "Grenze",
    "InknutAntiqua",
    "Kavoon",
    "MaShanZheng",
    "StintUltraCondensed",
    "Dekko",
    "Chicle",
    "MacondoSwashCaps",
    "Flamenco",
    "ChauPhilomeneOne",
    "Ramaraja",
    "LondrinaOutline",
    "Milonga",
    "Khmer",
    "Sancreek",
    "NovaRound",
    "TextMeOne",
    "KiteOne",
    "Junge",
    "SongMyung",
    "IMFellFrenchCanon",
    "Cagliostro",
    "Fenix",
    "SwankyandMooMoo",
    "RumRaisin",
    "Inika",
    "Paprika",
    "EastSeaDokdo",
    "Ranga",
    "Gaegu",
    "Modak",
    "Sura",
    "Buda",
    "Manuale",
    "Stoke",
    "Dorsa",
    "Thasadith",
    "LoversQuarrel",
    "CroissantOne",
    "LiuJianMaoCao",
    "LongCang",
    "HennyPenny",
    "NovaSlim",
    "Stalemate",
    "SedgwickAveDisplay",
    "Bokor",
    "HeptaSlab",
    "Underdog",
    "DeliusUnicase",
    "Mina",
    "Moul",
    "Wellfleet",
    "MeeraInimai",
    "OdorMeanChey",
    "Nokora",
    "Petrona",
    "NewRocker",
    "MarkoOne",
    "Offside",
    "Barrio",
    "Nosifer",
    "DellaRespira",
    "MonsieurLaDoulaise",
    "Julee",
    "BalooTammudu",
    "JotiOne",
    "NovaFlat",
    "Akronim",
    "Angkor",
    "EagleLake",
    "Kodchasan",
    "MaidenOrange",
    "Tillana",
    "UncialAntiqua",
    "CormorantUnicase",
    "Diplomata",
    "IMFellGreatPrimer",
    "Plaster",
    "KoHo",
    "StintUltraExpanded",
    "CrimsonPro",
    "LibreCaslonDisplay",
    "Griffy",
    "IMFellFrenchCanonSC",
    "ModernAntiqua",
    "Redressed",
    "LindenHill",
    "Chango",
    "IMFellDWPicaSC",
    "Revalia",
    "Margarine",
    "ElsieSwashCaps",
    "Galdeano",
    "ChelaOne",
    "AutourOne",
    "GlassAntiqua",
    "Ruthie",
    "UnifrakturCook",
    "BigshotOne",
    "LakkiReddy",
    "Montaga",
    "MrsSheppards",
    "Content",
    "Trykker",
    "Stylish",
    "RhodiumLibre",
    "Charmonman",
    "CuteFont",
    "MeieScript",
    "Iceberg",
    "Monofett",
    "Dangrek",
    "IrishGrover",
    "Oldenburg",
    "YeonSung",
    "Asar",
    "Felipa",
    "Fahkwang",
    "Smythe",
    "Sahitya",
    "MetalMania",
    "SnowburstOne",
    "Molle",
    "PurplePurse",
    "PoorStory",
    "HiMelody",
    "LibreBarcode128",
    "Devonshire",
    "LibreBarcode39Text",
    "MajorMonoDisplay",
    "Smokum",
    "AtomicAge",
    "Notable",
    "Asset",
    "Bayon",
    "Siemreap",
    "GamjaFlower",
    "Lancelot",
    "ZCOOLKuaiLe",
    "Arbutus",
    "LibreBarcode39Extended",
    "OriginalSurfer",
    "MedievalSharp",
    "Kantumruy",
    "Jomhuria",
    "CaesarDressing",
    "GoblinOne",
    "DiplomataSC",
    "LibreBarcode39ExtendedText",
    "Snippet",
    "Gorditas",
    "Freehand",
    "RaviPrakash",
    "KeaniaOne",
    "RugeBoogie",
    "DrSugiyama",
    "Risque",
    "GFSNeohellenic",
    "Chilanka",
    "JimNightshade",
    "LondrinaShadow",
    "IMFellDoublePicaSC",
    "SupermercadoOne",
    "JacquesFrancois",
    "Piedra",
    "AlmendraSC",
    "Romanesco",
    "Galindo",
    "TenaliRamakrishna",
    "AlmendraDisplay",
    "Flavors",
    "JollyLodger",
    "Metal",
    "KirangHaerang",
    "Solway",
    "Suwannaphum",
    "GeostarFill",
    "Kavivanar",
    "Warnes",
    "Sunshiney",
    "Astloch",
    "MiltonianTattoo",
    "Macondo",
    "ButterflyKids",
    "BungeeOutline",
    "NovaCut",
    "Taprom",
    "Kenia",
    "Sevillana",
    "MissFajardose",
    "EmblemaOne",
    "NovaOval",
    "Combo",
    "KumarOneOutline",
    "BigelowRules",
    "LondrinaSketch",
    "MrBedfort",
    "Preahvihear",
    "Federant",
    "LibreBarcode128Text",
    "Bonbon",
    "EricaOne",
    "Fascinate",
    "Butcherman",
    "Hanalei",
    "Gidugu",
    "SofadiOne",
    "BlackAndWhitePicture",
    "Miltonian",
    "BungeeHairline",
    "NovaScript",
    "Aubrey",
    "Geostar",
    "PasseroOne",
    "Dhurjati",
    "Peddana",
    "Moulpali",
    "Chenla",
    "Suravaram",
    "StalinistOne",
    "KdamThmor",
    "SingleDay",
    "Fasthand",
    "BioRhymeExpanded"
  ];
}
